@@ -17,7 +17,7 @@
 #'   considered as outlier can be recovered with the \code{as.data.frame}
 #'   function.
 #'
-#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
+#' @note There is also a \href{https://easystats.github.io/see/articles/performance.html}{\code{plot()}-method} implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}. \strong{Please note} that the range of the distance-values along the y-axis is re-scaled to range from 0 to 1.
 #'
 #' @details Outliers can be defined as particularly influential observations. Most methods rely on the computation of some distance metric, and the observations greater than a certain threshold are considered outliers. Importantly, outliers detection methods are meant to provide information to the researcher, rather than being an automatized procedure which mindless application is a substitute for thinking.
 #'
@@ -68,7 +68,7 @@
 #' \item \strong{Robust Mahalanobis Distance}:
 #' A robust version of Mahalanobis distance using an Orthogonalized
 #' Gnanadesikan-Kettenring pairwise estimator (Gnanadesikan \& Kettenring, 1972).
-#' Requires the \pkg{bigutilsr} package.
+#' Requires the \pkg{bigutilsr} package. See the \code{bigutilsr::dist_ogk()} function.
 #'
 #' \item \strong{Minimum Covariance Determinant (MCD)}:
 #' Another robust version of Mahalanobis. Leys et al. (2018) argue that Mahalanobis Distance is not a robust way to
@@ -108,7 +108,7 @@
 #' \subsection{Threshold specification}{
 #' Default thresholds are currently specified as follows:
 #'
-#' \code{
+#' \preformatted{
 #' list(
 #'   zscore = stats::qnorm(p = 1 - 0.025),
 #'   iqr = 1.5,
@@ -137,30 +137,55 @@
 #' }
 #'
 #' @examples
-#' # Univariate
-#' check_outliers(mtcars$mpg)
+#' data <- mtcars  # Size nrow(data) = 32
 #'
-#' # Multivariate
+#' # For single variables ------------------------------------------------------
+#' outliers_list <- check_outliers(data$mpg)  # Find outliers
+#' outliers_list  # Show the row index of the outliers
+#' as.numeric(outliers_list)  # The object is a binary vector...
+#' filtered_data <- data[!outliers_list, ] # And can be used to filter a dataframe
+#' nrow(filtered_data)  # New size, 28 (4 outliers removed)
+#'
+#'
+#' # For dataframes ------------------------------------------------------
+#' check_outliers(data)  # It works the same way on dataframes
+#'
+#' # You can also use multiple methods at once
+#' outliers_list <- check_outliers(data, method = c("mahalanobis",
+#'                                                  "iqr",
+#'                                                  "zscore"))
+#' outliers_list
+#' # Using `as.data.frame()`, we can access more details!
+#' outliers_info <- as.data.frame(outliers_list)
+#' head(outliers_info)
+#' outliers_info$Outlier  # Including the probability of being an outlier
+#' # And we can be more stringent in our outliers removal process
+#' filtered_data <- data[outliers_info$Outlier < 0.1, ]
+#'
+#' \dontrun{
+#' # You can also run all the methods
+#' check_outliers(data, method = "all")
+#'
+#' # For statistical models ---------------------------------------------
 #' # select only mpg and disp (continuous)
 #' mt1 <- mtcars[, c(1, 3, 4)]
 #' # create some fake outliers and attach outliers to main df
-#' mt2 <- rbind(mt1, data.frame(mpg = c(37, 40), disp = c(300, 400), hp = c(110, 120)))
+#' mt2 <- rbind(mt1, data.frame(mpg = c(37, 40), disp = c(300, 400),
+#'                              hp = c(110, 120)))
 #' # fit model with outliers
 #' model <- lm(disp ~ mpg + hp, data = mt2)
 #'
-#' ol <- check_outliers(model)
-#' # plot(ol)
-#' insight::get_data(mode)[ol, ]
+#' outliers_list <- check_outliers(model)
+#' # plot(outliers_list)
+#' insight::get_data(model)[outliers_list, ]  # Show outliers data
 #'
-#'
-#' check_outliers(model, method = c("mahalabonis", "mcd"))
-#' \dontrun{
-#' # This one takes some seconds to finish...
-#' check_outliers(model, method = "ics")
-#'
-#' # For dataframes
-#' check_outliers(mtcars)
-#' check_outliers(mtcars, method = "all")
+#' if (require("MASS")) {
+#'   check_outliers(model, method = c("mahalabonis", "mcd"))
+#' }
+#' if (require("ICS")) {
+#'   # This one takes some seconds to finish...
+#'   check_outliers(model, method = "ics")
+#' }
 #' }
 #' @importFrom insight n_obs get_predictors get_data
 #' @importFrom stats cooks.distance mahalanobis cov
@@ -232,6 +257,7 @@ check_outliers.default <- function(x, method = c("cook", "pareto"), threshold =
   attr(outlier, "threshold") <- thresholds
   attr(outlier, "method") <- method
   attr(outlier, "text_size") <- 3
+  attr(outlier, "influential_obs") <- .influential_obs(x)
   outlier
 }
 
@@ -284,7 +310,7 @@ check_outliers.data.frame <- function(x, method = "mahalanobis", threshold = NUL
 
   # Mahalanobis
   if ("mahalanobis" %in% c(method)) {
-    out <- c(out, .check_outliers_mahalanobis(x, threshold = thresholds$mahalanobis))
+    out <- c(out, .check_outliers_mahalanobis(x, threshold = thresholds$mahalanobis, ...))
   }
 
   # Robust Mahalanobis
@@ -501,11 +527,11 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
 #' @importFrom stats mahalanobis cov
-.check_outliers_mahalanobis <- function(x, threshold = NULL) {
+.check_outliers_mahalanobis <- function(x, threshold = NULL, ...) {
   out <- data.frame(Obs = 1:nrow(x))
 
   # Compute
-  out$Distance_Mahalanobis <- stats::mahalanobis(x, center = colMeans(x), cov = stats::cov(x))
+  out$Distance_Mahalanobis <- stats::mahalanobis(x, center = colMeans(x), cov = stats::cov(x), ...)
 
   # Filter
   out$Outlier_Mahalanobis <- as.numeric(out$Distance_Mahalanobis > threshold)
@@ -529,7 +555,8 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
   # Compute
-  out$Distance_Robust <- bigutilsr::dist_ogk(as.matrix(x))
+  U <- svd(scale(x))$u
+  out$Distance_Robust <- bigutilsr::dist_ogk(U)
 
   # Filter
   out$Outlier_Robust <- as.numeric(out$Distance_Robust > threshold)
@@ -718,6 +745,20 @@ as.numeric.check_outliers <- function(x, ...) {
 
 
 
+# influential observations data --------
+
+.influential_obs <- function(x) {
+  tryCatch(
+    {
+      .diag_influential_obs(x)
+    },
+    error = function(e) {
+      NULL
+    }
+  )
+}
+
+
 
 
 
