@@ -48,12 +48,11 @@
 #'   m3 <- lmer(Petal.Length ~ Sepal.Length + (1 | Species), data = iris)
 #'   compare_performance(m1, m2, m3)
 #' }
-#'
 #' @importFrom insight is_model_supported all_models_equal get_response
 #' @importFrom bayestestR bayesfactor_models
 #' @inheritParams model_performance.lm
 #' @export
-compare_performance <- function(..., metrics = "all", rank = FALSE,verbose = TRUE) {
+compare_performance <- function(..., metrics = "all", rank = FALSE, verbose = TRUE) {
   objects <- list(...)
   object_names <- match.call(expand.dots = FALSE)$`...`
 
@@ -132,7 +131,7 @@ compare_performance <- function(..., metrics = "all", rank = FALSE,verbose = TRU
   }
 
   # recode some indices, so higher values = better fit
-  for (i in c("AIC", "BIC", "RMSE", "Sigma")) {
+  for (i in c("AIC", "AICc", "BIC", "RMSE", "Sigma")) {
     if (i %in% colnames(out)) {
       out[[i]] <- 1 - out[[i]]
     }
