@@ -17,7 +17,8 @@
 #'    0.7 < \ifelse{html}{\out{&alpha;}}{\eqn{\alpha}{alpha}} < 0.8 is acceptable,
 #'    and everything > 0.8 is good or excellent.
 #'
-#' @references Bland, J. M., \& Altman, D. G. Statistics notes: Cronbach's alpha. BMJ 1997;314:572. 10.1136/bmj.314.7080.572
+#' @references Bland, J. M., \& Altman, D. G. Statistics notes: Cronbach's
+#'   alpha. BMJ 1997;314:572. 10.1136/bmj.314.7080.572
 #'
 #' @examples
 #' data(mtcars)
@@ -48,6 +49,13 @@ cronbachs_alpha.data.frame <- function(x) {
 
 
 
+#' @export
+cronbachs_alpha.matrix <- function(x) {
+  cronbachs_alpha(as.data.frame(x))
+}
+
+
+
 #' @export
 cronbachs_alpha.parameters_pca <- function(x) {
   ## TODO change to data_name once parameters 0.10.0 is on CRAN
