@@ -1,6 +1,6 @@
-#' @importFrom insight format_value format_p format_bf parameters_table
+#' @importFrom insight format_value format_p format_bf format_table
 #' @export
-format.compare_performance <- function(x, digits = 2, format = NULL, ...) {
+format.compare_performance <- function(x, digits = 2, ...) {
   # if we have ranking, add score and remove incomplete indices in print
   if ("Performance_Score" %in% colnames(x)) {
     x$Performance_Score <- insight::format_value(x$Performance_Score, as_percent = TRUE)
@@ -10,12 +10,12 @@ format.compare_performance <- function(x, digits = 2, format = NULL, ...) {
     x$BF[is.na(x$BF)] <- 1
     # x$BF <- insight::format_bf(x$BF)
   }
-  insight::parameters_table(x)
+  insight::format_table(x, digits = digits, ...)
 }
 
 
 #' @export
-format.performance_model <- function(x, digits = 2, format = NULL, ...) {
+format.performance_model <- function(x, digits = 2, ...) {
   # format p-values for meta-analysis
-  insight::parameters_table(x)
+  insight::format_table(x, digits = digits, ...)
 }
