@@ -165,16 +165,23 @@
 
 
 .remove_backticks_from_parameter_names <- function(x) {
-  if (is.data.frame(x) && "Parameter" %in% colnames(x)) {
-    x$Parameter <- gsub("`", "", x$Parameter, fixed = TRUE)
+  if (is.data.frame(x)) {
+    if ("Parameter" %in% colnames(x)) {
+      x$Parameter <- gsub("`", "", x$Parameter, fixed = TRUE)
+    }
+    if ("Term" %in% colnames(x)) {
+      x$Term <- gsub("`", "", x$Term, fixed = TRUE)
+    }
   }
+
   x
 }
 
 
+
 #' @importFrom insight get_sigma
-.get_sigma <- function(model) {
-  s <- insight::get_sigma(model)
+.get_sigma <- function(model, verbose = TRUE) {
+  s <- insight::get_sigma(model, verbose = verbose)
   if (!is.null(s)) {
     as.numeric(s)
   } else {
