@@ -3,7 +3,7 @@
 #' Compute indices of model performance for regression models.
 #'
 #' @param model A model.
-#' @param metrics Can be \code{"all"}, \code{"common"} or a character vector of metrics to be computed (some of \code{c("AIC", "BIC", "R2", "RMSE", "SIGMA", "LOGLOSS", "PCP", "SCORE")}). \code{"common"} will compute AIC, BIC, R2 and RMSE.
+#' @param metrics Can be \code{"all"}, \code{"common"} or a character vector of metrics to be computed (some of \code{c("AIC", "AICc", "BIC", "R2", "R2_adj", "RMSE", "SIGMA", "LOGLOSS", "PCP", "SCORE")}). \code{"common"} will compute AIC, BIC, R2 and RMSE.
 #' @param verbose Toggle off warnings.
 #' @param ... Arguments passed to or from other methods.
 #'
@@ -12,6 +12,7 @@
 #' @details Depending on \code{model}, following indices are computed:
 #' \itemize{
 #'   \item{\strong{AIC}} {Akaike's Information Criterion, see \code{?stats::AIC}}
+#'   \item{\strong{AICc}} {Second-order (or small sample) AIC with a correction for small sample sizes}
 #'   \item{\strong{BIC}} {Bayesian Information Criterion, see \code{?stats::BIC}}
 #'   \item{\strong{R2}} {r-squared value, see \code{\link{r2}}}
 #'   \item{\strong{R2_adj}} {adjusted r-squared, see \code{\link{r2}}}
@@ -54,81 +55,115 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
 
   # AIC -------------
   if ("AIC" %in% toupper(metrics)) {
-    out$AIC <- tryCatch({
-      performance_aic(model)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$AIC <- tryCatch(
+      {
+        performance_aic(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
+  }
+
+  # AICc -------------
+  if ("AICC" %in% toupper(metrics)) {
+    out$AICc <- tryCatch(
+      {
+        performance_aicc(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # BIC -------------
   if ("BIC" %in% toupper(metrics)) {
-    out$BIC <- tryCatch({
-      .get_BIC(model)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$BIC <- tryCatch(
+      {
+        .get_BIC(model)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # R2 -------------
-  if ("R2" %in% toupper(metrics)) {
-    R2 <- tryCatch({
-      r2(model, verbose = verbose)
-    },
-    error = function(e) {
-      NULL
-    })
+  if (any(c("R2", "R2_ADJ") %in% toupper(metrics))) {
+    R2 <- tryCatch(
+      {
+        r2(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
     if (!is.null(R2)) {
       attrib$r2 <- attributes(R2)
-      out <- c(out, R2)
+      if ("R2" %in% toupper(metrics) && "R2" %in% names(R2)) {
+        out$R2 <- R2$R2
+      }
+      if ("R2_ADJ" %in% toupper(metrics) && "R2_adjusted" %in% names(R2)) {
+        out$R2_adjusted <- R2$R2_adjusted
+      }
+      if (!any(c("R2", "R2_adj") %in% names(R2))) {
+        out <- c(out, R2)
+      }
     }
   }
 
   # RMSE -------------
   if ("RMSE" %in% toupper(metrics)) {
-    out$RMSE <- tryCatch({
-      performance_rmse(model, verbose = verbose)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$RMSE <- tryCatch(
+      {
+        performance_rmse(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # SIGMA -------------
   if ("SIGMA" %in% toupper(metrics)) {
-    out$Sigma <- tryCatch({
-      .get_sigma(model)
-    },
-    error = function(e) {
-      NULL
-    })
+    out$Sigma <- tryCatch(
+      {
+        .get_sigma(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
   # LOGLOSS -------------
   if (("LOGLOSS" %in% toupper(metrics)) && isTRUE(info$is_binomial)) {
-    out$Log_loss <- tryCatch({
-      .logloss <- performance_logloss(model, verbose = verbose)
-      if (!is.na(.logloss)) {
-        .logloss
-      } else {
+    out$Log_loss <- tryCatch(
+      {
+        .logloss <- performance_logloss(model, verbose = verbose)
+        if (!is.na(.logloss)) {
+          .logloss
+        } else {
+          NULL
+        }
+      },
+      error = function(e) {
         NULL
       }
-    },
-    error = function(e) {
-      NULL
-    })
+    )
   }
 
   # SCORE -------------
   if (("SCORE" %in% toupper(metrics)) && (isTRUE(info$is_binomial) || isTRUE(info$is_count))) {
-    .scoring_rules <- tryCatch({
-      performance_score(model, verbose = verbose)
-    },
-    error = function(e) {
-      NULL
-    })
+    .scoring_rules <- tryCatch(
+      {
+        performance_score(model, verbose = verbose)
+      },
+      error = function(e) {
+        NULL
+      }
+    )
     if (!is.null(.scoring_rules)) {
       if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
       if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
@@ -137,12 +172,14 @@ model_performance.lm <- function(model, metrics = "all", verbose = TRUE, ...) {
 
   # PCP -------------
   if (("PCP" %in% toupper(metrics)) && isTRUE(info$is_binomial) && isFALSE(info$is_multinomial) && isFALSE(info$is_ordinal)) {
-    out$PCP <- tryCatch({
-      performance_pcp(model, verbose = verbose)$pcp_model
-    },
-    error = function(e) {
-      NULL
-    })
+    out$PCP <- tryCatch(
+      {
+        performance_pcp(model, verbose = verbose)$pcp_model
+      },
+      error = function(e) {
+        NULL
+      }
+    )
   }
 
 
@@ -275,6 +312,9 @@ model_performance.betaor <- model_performance.logitor
 #' @export
 model_performance.betamfx <- model_performance.logitor
 
+#' @export
+model_performance.model_fit <- model_performance.logitor
+
 
 
 
