@@ -2,7 +2,7 @@
 #'
 #' Compute indices of model performance for mixed models.
 #'
-#' @param metrics Can be \code{"all"}, \code{"common"} or a character vector of metrics to be computed (some of \code{c("AIC", "BIC", "R2", "ICC", "RMSE", "SIGMA", "LOGLOSS", "SCORE")}). \code{"common"} will compute AIC, BIC, R2, ICC and RMSE.
+#' @param metrics Can be \code{"all"}, \code{"common"} or a character vector of metrics to be computed (some of \code{c("AIC", "AICc", "BIC", "R2", "ICC", "RMSE", "SIGMA", "LOGLOSS", "SCORE")}). \code{"common"} will compute AIC, BIC, R2, ICC and RMSE.
 #' @param ... Arguments passed to or from other methods.
 #' @inheritParams r2_nakagawa
 #' @inheritParams model_performance.lm
@@ -28,39 +28,48 @@ model_performance.merMod <- function(model, metrics = "all", verbose = TRUE, ...
     metrics[tolower(metrics) == "log_loss"] <- "LOGLOSS"
   }
 
+  # all available metrics
+  all_metrics <- c("AIC", "AICc", "BIC", "R2", "ICC", "RMSE", "SIGMA", "LOGLOSS", "SCORE")
+
   if (all(metrics == "all")) {
-    metrics <- c("AIC", "BIC", "R2", "ICC", "RMSE", "SIGMA", "LOGLOSS", "SCORE")
+    metrics <- all_metrics
   } else if (all(metrics == "common")) {
     metrics <- c("AIC", "BIC", "R2", "ICC", "RMSE")
   }
 
+  # check for valid input
+  metrics <- .check_bad_metrics(metrics, all_metrics, verbose)
+
   mi <- insight::model_info(model)
 
   out <- list()
-  if ("AIC" %in% metrics) {
+  if ("AIC" %in% toupper(metrics)) {
     out$AIC <- performance_aic(model)
   }
-  if ("BIC" %in% metrics) {
+  if ("AICC" %in% toupper(metrics)) {
+    out$AIC <- performance_aic(model)
+  }
+  if ("BIC" %in% toupper(metrics)) {
     out$BIC <- .get_BIC(model)
   }
-  if ("R2" %in% metrics) {
+  if ("R2" %in% toupper(metrics)) {
     rsq <- suppressWarnings(r2(model))
     if (!all(is.na(rsq))) out <- c(out, rsq)
   }
-  if ("ICC" %in% metrics) {
+  if ("ICC" %in% toupper(metrics)) {
     icc_mm <- suppressWarnings(icc(model))
     if (!all(is.na(icc_mm))) out$ICC <- icc_mm$ICC_adjusted
   }
-  if ("RMSE" %in% metrics) {
+  if ("RMSE" %in% toupper(metrics)) {
     out$RMSE <- performance_rmse(model, verbose = verbose)
   }
   if ("SIGMA" %in% toupper(metrics)) {
-    out$Sigma <- .get_sigma(model)
+    out$Sigma <- .get_sigma(model, verbose = verbose)
   }
-  if (("LOGLOSS" %in% metrics) && mi$is_binomial) {
+  if (("LOGLOSS" %in% toupper(metrics)) && mi$is_binomial) {
     out$Log_loss <- performance_logloss(model, verbose = verbose)
   }
-  if (("SCORE" %in% metrics) && (mi$is_binomial || mi$is_count)) {
+  if (("SCORE" %in% toupper(metrics)) && (mi$is_binomial || mi$is_count)) {
     .scoring_rules <- performance_score(model, verbose = verbose)
     if (!is.na(.scoring_rules$logarithmic)) out$Score_log <- .scoring_rules$logarithmic
     if (!is.na(.scoring_rules$spherical)) out$Score_spherical <- .scoring_rules$spherical
