@@ -46,8 +46,8 @@
 #' m <- glm(formula = vs ~ hp + wt, family = binomial, data = mtcars)
 #' performance_pcp(m)
 #' performance_pcp(m, method = "Gelman-Hill")
-#' @importFrom stats predict qnorm binomial predict.glm pchisq logLik weights as.formula glm
-#' @importFrom insight get_response n_obs model_info find_response get_data
+#' @importFrom stats predict qnorm binomial predict.glm pchisq weights as.formula glm
+#' @importFrom insight get_response n_obs model_info find_response get_data get_loglikelihood
 #' @export
 performance_pcp <- function(model, ci = 0.95, method = "Herron", verbose = TRUE) {
   # fix special cases
@@ -87,8 +87,8 @@ performance_pcp <- function(model, ci = 0.95, method = "Herron", verbose = TRUE)
   y_full <- .recode_to_zero(insight::get_response(model))
   y_null <- .recode_to_zero(insight::get_response(m0))
 
-  n_full <- insight::n_obs(model)
-  n_null <- insight::n_obs(m0)
+  n_full <- suppressWarnings(insight::n_obs(model))
+  n_null <- suppressWarnings(insight::n_obs(m0))
 
   pr_full <- stats::predict(model, type = "response")
   pr_null <- stats::predict(m0, type = "response")
@@ -102,7 +102,7 @@ performance_pcp <- function(model, ci = 0.95, method = "Herron", verbose = TRUE)
     lower.tail = TRUE
   )
 
-  lrt.chisq <- 2 * abs(stats::logLik(model) - stats::logLik(m0))
+  lrt.chisq <- 2 * abs(insight::get_loglikelihood(model) - insight::get_loglikelihood(m0))
 
   structure(
     class = "performance_pcp",
@@ -124,8 +124,8 @@ performance_pcp <- function(model, ci = 0.95, method = "Herron", verbose = TRUE)
   y_full <- .recode_to_zero(insight::get_response(model))
   y_null <- .recode_to_zero(insight::get_response(m0))
 
-  n_full <- insight::n_obs(model)
-  n_null <- insight::n_obs(m0)
+  n_full <- suppressWarnings(insight::n_obs(model))
+  n_null <- suppressWarnings(insight::n_obs(m0))
 
   pr_full <- stats::predict(model, type = "response")
   pr_null <- stats::predict(m0, type = "response")
@@ -139,7 +139,7 @@ performance_pcp <- function(model, ci = 0.95, method = "Herron", verbose = TRUE)
     lower.tail = TRUE
   )
 
-  lrt.chisq <- 2 * abs(stats::logLik(model) - stats::logLik(m0))
+  lrt.chisq <- 2 * abs(insight::get_loglikelihood(model) - insight::get_loglikelihood(m0))
 
   structure(
     class = "performance_pcp",
