@@ -112,7 +112,11 @@ performance_score <- function(model, verbose = TRUE) {
   }
 
   pr <- .predict_score_y(model)
-  resp <- .factor_to_numeric(resp)
+  resp <- if (minfo$is_binomial) {
+    .recode_to_zero(resp)
+  } else {
+    .factor_to_numeric(resp)
+  }
   p_y <- prob_fun(resp, mean = pr$pred, pis = pr$pred_zi, sum(resp))
 
   quadrat_p <- sum(p_y^2)
