@@ -19,7 +19,7 @@
 #'   and credible intervals for the R2 values are saved as attributes.
 #'
 #' @details \code{r2_bayes()} returns an "unadjusted" R2 value. See \code{\link{r2_loo}}
-#'   to calculate a LOO-adjusted R2, which comes conceptionally closer to an
+#'   to calculate a LOO-adjusted R2, which comes conceptually closer to an
 #'   adjusted R2 measure.
 #'   \cr \cr
 #'   For mixed models, the conditional and marginal R2 are returned. The marginal
@@ -44,8 +44,6 @@
 #'   )
 #'   r2_bayes(model)
 #' }
-#'
-#'
 #' \dontrun{
 #' if (require("BayesFactor")) {
 #'   data(mtcars)
@@ -113,7 +111,7 @@ r2_bayes <- function(model, robust = TRUE, ci = .89, verbose = TRUE, ...) {
 
 #' @export
 #' @rdname r2_bayes
-r2_posterior <- function(model, ...){
+r2_posterior <- function(model, ...) {
   UseMethod("r2_posterior")
 }
 
@@ -195,24 +193,26 @@ r2_posterior.stanmvreg <- function(model, verbose = TRUE, ...) {
 }
 
 
-#' @param average Compute model-averaged index? See
-#'   \code{\link[bayestestR:weighted_posteriors]{bayestestR::weighted_posteriors()}}.
+#' @param average Compute model-averaged index? See \code{\link[bayestestR:weighted_posteriors]{bayestestR::weighted_posteriors()}}.
 #' @inheritParams bayestestR::weighted_posteriors
+#' @inheritParams r2_bayes
 #' @importFrom insight get_parameters get_response find_predictors
 #' @importFrom stats median mad sd
 #' @importFrom bayestestR point_estimate hdi
 #' @importFrom utils packageVersion
 #' @export
 #' @rdname r2_bayes
-r2_posterior.BFBayesFactor <- function(model, average = FALSE, prior_odds = NULL, ...){
+r2_posterior.BFBayesFactor <- function(model, average = FALSE, prior_odds = NULL, verbose = TRUE, ...) {
   mi <- insight::model_info(model)
   if (!mi$is_linear || mi$is_correlation || mi$is_ttest || mi$is_binomial || mi$is_meta) {
-    warning("Can produce R2 only for linear models.", call. = FALSE)
+    if (verbose) {
+      warning("Can produce R2 only for linear models.", call. = FALSE)
+    }
     return(NULL)
   }
 
   if (average) {
-    return(.r2_posterior_model_average(model, prior_odds = prior_odds))
+    return(.r2_posterior_model_average(model, prior_odds = prior_odds, verbose = verbose))
   }
 
   if (!requireNamespace("rstantools", quietly = TRUE)) {
@@ -234,7 +234,7 @@ r2_posterior.BFBayesFactor <- function(model, average = FALSE, prior_odds = NULL
 
   # match?
   if ((length(colnames(params)) != length(colnames(mm))) ||
-      !all(colnames(params) == colnames(mm))) {
+    !all(colnames(params) == colnames(mm))) {
     if (utils::packageVersion("BayesFactor") < package_version("0.9.12.4.3")) {
       stop("R2 for BayesFactor models with random effects requires BayesFactor v0.9.12.4.3 or higher.", call. = FALSE)
     }
@@ -265,7 +265,7 @@ r2_posterior.BFBayesFactor <- function(model, average = FALSE, prior_odds = NULL
 
 #' @importFrom bayestestR weighted_posteriors
 #' @keywords internal
-.r2_posterior_model_average <- function(model, prior_odds = NULL) {
+.r2_posterior_model_average <- function(model, prior_odds = NULL, verbose = TRUE) {
   if (!requireNamespace("BayesFactor", quietly = TRUE)) {
     stop("Package `BayesFactor` needed for this function to work. Please install it.")
   }
@@ -273,6 +273,13 @@ r2_posterior.BFBayesFactor <- function(model, average = FALSE, prior_odds = NULL
   BFMods <- bayestestR::bayesfactor_models(model, verbose = FALSE)
   has_random <- !is.null(insight::find_predictors(model, effects = "random", flatten = TRUE))
 
+  if (any(is.na(BFMods$BF) | is.infinite(BFMods$BF))) {
+    if (verbose) {
+      warning("Can't compute model-averaged index. One or more Bayes factors are NA or infinite.", call. = FALSE)
+    }
+    return(NULL)
+  }
+
   # extract parameters
   intercept_only <- which(BFMods$Model == "1")
   params <- vector(mode = "list", length = nrow(BFMods))
@@ -302,8 +309,10 @@ r2_posterior.BFBayesFactor <- function(model, average = FALSE, prior_odds = NULL
   posterior_odds <- prior_odds * BFMods$BF
   posterior_odds <- posterior_odds[-1] / posterior_odds[1]
 
-  do.call(bayestestR::weighted_posteriors,
-          c(params, list(missing = 0, prior_odds = posterior_odds)))
+  do.call(
+    bayestestR::weighted_posteriors,
+    c(params, list(missing = 0, prior_odds = posterior_odds))
+  )
 }
 
 
