@@ -1,5 +1,15 @@
 #' @rdname test_performance
-#' @param estimator Applied when comparing regression models using \code{test_likelihoodratio()}. Corresponds to the different estimators for the standard deviation of the errors. If \code{estimator="OLS"} (default), then it uses the same method as \code{anova(..., test="LRT")} implemented in base R, i.e., scaling by n-k (the unbiased OLS estimator) and using this estimator under the alternative hypothesis. If \code{estimator="ML"}, which is for instance used by \code{lrtest(...)} in package \pkg{lmtest}, the scaling is done by n (the biased ML estimator) and the estimator under the null hypothesis. In moderately large samples, the differences should be negligible, but it is possible that OLS would perform slightly better in small samples with Gaussian errors.
+#' @param estimator Applied when comparing regression models using
+#'   \code{test_likelihoodratio()}. Corresponds to the different estimators for
+#'   the standard deviation of the errors. If \code{estimator="OLS"} (default),
+#'   then it uses the same method as \code{anova(..., test="LRT")} implemented
+#'   in base R, i.e., scaling by n-k (the unbiased OLS estimator) and using this
+#'   estimator under the alternative hypothesis. If \code{estimator="ML"}, which
+#'   is for instance used by \code{lrtest(...)} in package \pkg{lmtest}, the
+#'   scaling is done by n (the biased ML estimator) and the estimator under the
+#'   null hypothesis. In moderately large samples, the differences should be
+#'   negligible, but it is possible that OLS would perform slightly better in
+#'   small samples with Gaussian errors.
 #' @export
 test_likelihoodratio <- function(..., estimator = "ML") {
   UseMethod("test_likelihoodratio")
@@ -12,6 +22,12 @@ test_likelihoodratio <- function(..., estimator = "ML") {
 performance_lrt <- test_likelihoodratio
 
 
+# Short name for test_likelihoodratio using the test_* naming convention
+#' @rdname test_performance
+#' @export
+test_lrt <- test_likelihoodratio
+
+
 #' @importFrom insight ellipsis_info
 #' @export
 test_likelihoodratio.default <- function(..., estimator = "ML") {
@@ -38,16 +54,19 @@ test_likelihoodratio.default <- function(..., estimator = "ML") {
 
 
 
-
-
-
-
 #' @importFrom insight is_model get_df get_loglikelihood
 #' @importFrom stats pchisq
 #' @export
 test_likelihoodratio.ListNestedRegressions <- function(objects, estimator = "ML", ...) {
   dfs <- sapply(objects, insight::get_df, type = "model")
-  dfs_diff <- c(NA, diff(sapply(objects, insight::get_df, type = "model")))
+
+  # sort by df
+  if (!all(sort(dfs) == dfs) && !all(sort(dfs) == rev(dfs))) {
+    objects <- objects[order(dfs)]
+    dfs <- dfs[order(dfs)]
+  }
+
+  dfs_diff <- c(NA, diff(dfs))
 
   # lmtest::lrtest()
   if (tolower(estimator) %in% c("ml", "mle")) {
@@ -64,7 +83,6 @@ test_likelihoodratio.ListNestedRegressions <- function(objects, estimator = "ML"
     )
 
     out <- cbind(.test_performance_init(objects), out)
-
   } else {
     out <- .test_wald(objects, test = "LRT")
     out$df <- dfs # Replace residual df with model's df
@@ -104,4 +122,3 @@ test_likelihoodratio_ListLavaan <- function(..., objects = NULL) {
   class(out) <- c("test_likelihoodratio", "see_test_likelihoodratio", "data.frame")
   out
 }
-
