@@ -245,8 +245,7 @@ test_vuong.ListNonNestedRegressions <- function(objects, reference = 1, ...) {
 # all(ref$B == rez$B)
 # all(ref$sc == rez$sc)
 
-#' @importFrom insight get_sigma
-#' @importFrom stats vcov
+#' @importFrom insight get_sigma get_varcov n_obs
 .test_vuong_AB <- function(model) {
   # A, B as defined in Vuong Eq (2.1) and (2.2)
 
@@ -264,7 +263,7 @@ test_vuong.ListNonNestedRegressions <- function(objects, reference = 1, ...) {
   } else {
     scaling <- insight::get_sigma(model)^2
     if (is.null(scaling) || is.na(scaling)) scaling <- 1
-    covmat <- n * stats::vcov(model)
+    covmat <- n * insight::get_varcov(model, component = "conditional")
   }
 
   A <- chol2inv(chol(covmat))
